num

Module bigint

Modules

big_digit

Structs

BigInt
A big signed integer type.
BigUint
A big unsigned integer type.

Enums

ParseBigIntError
Sign
A Sign is a BigInt’s composing element.

Constants

ZERO_BIG_DIGIT

Traits

RandBigInt
ToBigInt
A generic trait for converting a value to a BigInt.
ToBigUint
A generic trait for converting a value to a BigUint.

Type Aliases

BigDigit
A BigDigit is a BigUint’s composing element.
DoubleBigDigit
A DoubleBigDigit is the internal type used to do the computations. Its size is the double of the size of BigDigit.